@@ -211,11 +211,25 @@ class OEMHandler(generic.OEMHandler):
             self._mrethidx = rsp['data'][0]
         return self._mrethidx
 
+    def get_screenshot(self, outfile):
+        if self.has_xcc:
+            return self.immhandler.get_screenshot(outfile)
+        return {}
+
     def remove_storage_configuration(self, cfgspec):
         if self.has_xcc:
             return self.immhandler.remove_storage_configuration(cfgspec)
         return super(OEMHandler, self).remove_storage_configuration()
 
+    def get_ikvm_methods(self):
+        if self.has_xcc:
+            return ['url']
+
+    def get_ikvm_launchdata(self):
+        if self.has_xcc:
+            return self.immhandler.get_ikvm_launchdata()
+        return {}
+
     def clear_storage_arrays(self):
         if self.has_xcc:
             return self.immhandler.clear_storage_arrays()
@@ -346,7 +360,7 @@ class OEMHandler(generic.OEMHandler):
             return self.smmhandler.get_ntp_servers()
         if self.has_tsma:
             return self.tsmahandler.get_ntp_servers()
-        return None
+        return ()
 
     def set_ntp_enabled(self, enabled):
         if self.has_tsm or self.has_ami or self.has_asrock:
@@ -671,9 +685,11 @@ class OEMHandler(generic.OEMHandler):
                                         led_status_default)
             yield (name, {'status': status})
 
-    def set_identify(self, on, duration):
+    def set_identify(self, on, duration, blink):
         if on and not duration and self.is_sd350:
             self.ipmicmd.xraw_command(netfn=0x3a, command=6, data=(1, 1))
+        elif self.has_xcc:
+            self.immhandler.set_identify(on, duration, blink)
         else:
             raise pygexc.UnsupportedFunctionality()
 
@@ -718,27 +734,28 @@ class OEMHandler(generic.OEMHandler):
                 fru['FRU Number'] = bextra[0]
                 fru['Revision'] = bextra[4]
                 macs = bextra[6]
-                macprefix = None
-                idx = 0
-                endidx = len(macs) - 5
-                macprefix = None
-                while idx < endidx:
-                    currmac = macs[idx:idx + 6]
-                    if not isinstance(currmac, bytearray):
-                        # invalid vpd format, abort attempts to extract
-                        # mac in this way
-                        break
-                    if currmac == b'\x00\x00\x00\x00\x00\x00':
-                        break
-                    # VPD may veer off, detect and break off
-                    if macprefix is None:
-                        macprefix = currmac[:3]
-                    elif currmac[:3] != macprefix:
-                        break
-                    ms = mac_format.format(*currmac)
-                    ifidx = idx / 6 + 1
-                    fru['MAC Address {0}'.format(ifidx)] = ms
-                    idx = idx + 6
+                if macs:
+                    macprefix = None
+                    idx = 0
+                    endidx = len(macs) - 5
+                    macprefix = None
+                    while idx < endidx:
+                        currmac = macs[idx:idx + 6]
+                        if not isinstance(currmac, bytearray):
+                            # invalid vpd format, abort attempts to extract
+                            # mac in this way
+                            break
+                        if currmac == b'\x00\x00\x00\x00\x00\x00':
+                            break
+                        # VPD may veer off, detect and break off
+                        if macprefix is None:
+                            macprefix = currmac[:3]
+                        elif currmac[:3] != macprefix:
+                            break
+                        ms = mac_format.format(*currmac)
+                        ifidx = idx / 6 + 1
+                        fru['MAC Address {0}'.format(ifidx)] = ms
+                        idx = idx + 6
             except (AttributeError, KeyError, IndexError):
                 pass
             if self.has_xcc and name and name.startswith('PSU '):
@@ -825,7 +842,7 @@ class OEMHandler(generic.OEMHandler):
                 return False
         return False
 
-    def get_oem_firmware(self, bmcver, components):
+    def get_oem_firmware(self, bmcver, components, category):
         if self.has_tsm or self.has_ami or self.has_asrock:
             command = firmware.get_categories()["firmware"]
             fw_cmd = self.get_cmd_type("firmware", command)
@@ -848,7 +865,7 @@ class OEMHandler(generic.OEMHandler):
                                      bios_versions,
                                      self.has_asrock)
         elif self.has_imm:
-            return self.immhandler.get_firmware_inventory(bmcver, components)
+            return self.immhandler.get_firmware_inventory(bmcver, components, category)
         elif self.is_fpc:
             return nextscale.get_fpc_firmware(bmcver, self.ipmicmd,
                                               self._fpc_variant)
@@ -1172,6 +1189,13 @@ class OEMHandler(generic.OEMHandler):
                 else:
                     raise
 
+    def get_update_status(self):
+        if self.is_fpc or self.has_tsma:
+            return "ready"
+        if self.has_xcc:
+            return self.immhandler.get_update_status()
+        return super(OEMHandler, self).get_update_status()
+
     def update_firmware(self, filename, data=None, progress=None, bank=None):
         if self.has_xcc:
             return self.immhandler.update_firmware(
@@ -1190,19 +1214,19 @@ class OEMHandler(generic.OEMHandler):
         if self.has_xcc:
             return self.immhandler.get_description()
         if self.is_fpc:
-            return {'height': self._fpc_variant, 'slot': 0}
+            return {'height': self._fpc_variant & 0xf, 'slot': 0}
         return super(OEMHandler, self).get_description()
 
-    def get_extended_bmc_configuration(self):
+    def get_extended_bmc_configuration(self, hideadvanced=True):
         if self.has_xcc:
-            return self.immhandler.get_extended_bmc_configuration()
+            return self.immhandler.get_extended_bmc_configuration(hideadvanced=hideadvanced)
         return super(OEMHandler, self).get_extended_bmc_configuration()
 
     def get_bmc_configuration(self):
         if self.has_xcc:
             return self.immhandler.get_bmc_configuration()
         if self.is_fpc:
-            return self.smmhandler.get_bmc_configuration()
+            return self.smmhandler.get_bmc_configuration(self._fpc_variant)
         if self.has_tsma:
             return self.tsmahandler.get_bmc_configuration()
         return super(OEMHandler, self).get_bmc_configuration()
